@@ -1,7 +1,7 @@
 /**
  * Handles building of classes
  *
- *  Copyright (C) 2011, 2012, 2013, 2014, 2015 Free Software Foundation, Inc.
+ *  Copyright (C) 2011, 2012, 2013, 2014, 2015, 2016 Free Software Foundation, Inc.
  *
  *  This file is part of GNU ease.js.
  *
@@ -116,14 +116,14 @@ var util    = require( './util' ),
  * @constructor
  */
 module.exports = exports =
-function ClassBuilder( warn_handler, member_builder, visibility_factory )
+function ClassBuilder( warn_handler, member_builder, visibility_factory, ector )
 {
     // allow ommitting the 'new' keyword
     if ( !( this instanceof exports ) )
     {
         // module.exports for Closure Compiler
         return new module.exports(
-            warn_handler, member_builder, visibility_factory
+            warn_handler, member_builder, visibility_factory, ector
         );
     }
 
@@ -145,6 +145,11 @@ function ClassBuilder( warn_handler, member_builder, visibility_factory )
      */
     this._visFactory = visibility_factory;
 
+    /**
+     * Error constructor generator
+     * @type {ErrorCtor}
+     */
+    this._ector = ector;
 
     /**
      * Class id counter, to be increment on each new definition
@@ -408,6 +413,22 @@ exports.prototype.build = function extend( _, __ )
         }
     }
 
+    // we transparently handle extending errors in a sane manner, which is
+    // traditionally a huge mess (you're welcome)
+    if ( this._ector && this._ector.isError( base ) )
+    {
+        // declare public properties (otherwise, they'll be confined to the
+        // private visibility object in ES5+ environments)
+        props.message = '';
+        props.stack   = '';
+
+        // user-provided constructor
+        var ector_own = props.__construct;
+
+        // everything else is handled by the constructor
+        props.__construct = this._ector.createCtor( base, cname, ector_own );
+    }
+
     // increment class identifier
     this._classId++;
 
