@@ -1,7 +1,7 @@
 /**
  * Validation rules for members
  *
- *  Copyright (C) 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
+ *  Copyright (C) 2011, 2012, 2013, 2014, 2015 Free Software Foundation, Inc.
  *
  *  This file is part of GNU ease.js.
  *
@@ -233,7 +233,7 @@ exports.prototype.validateMethod = function(
 
         // do not allow overriding concrete methods with abstract unless the
         // abstract method is weak
-        if ( keywords[ 'abstract' ]
+        if ( ( keywords[ 'abstract' ] && !keywords[ 'override' ] )
             && !( keywords.weak )
             && !( prev_keywords[ 'abstract' ] )
         )
