@@ -208,7 +208,9 @@ Trait.extend = function( /* ... */ )
     }
 
     // and here we can see that traits are quite literally abstract classes
-    var tclass = base.extend( dfn );
+    var tclass = ( ext_base )
+        ? base.extend( ext_base, dfn )
+        : base.extend( dfn );
 
     Trait.__trait   = type;
     Trait.__acls    = tclass;
@@ -661,12 +663,12 @@ function mixin( trait, dfn, tc, base )
  *
  * @return {undefined}
  */
-function mixinCls( cls, dfn, iname )
+function mixinCls( cls, dfn, iname, inparent )
 {
     var methods = cls.___$$methods$$;
 
-    mixMethods( methods['public'], dfn, 'public', iname );
-    mixMethods( methods['protected'], dfn, 'protected', iname );
+    mixMethods( methods['public'], dfn, 'public', iname, inparent );
+    mixMethods( methods['protected'], dfn, 'protected', iname, inparent );
 
     // if this class inherits from another class that is *not* the base
     // class, recursively process its methods; otherwise, we will have
@@ -674,7 +676,7 @@ function mixinCls( cls, dfn, iname )
     var parent = methods['public'].___$$parent$$;
     if ( parent && ( parent.constructor !== ClassBuilder.ClassBase ) )
     {
-        mixinCls( parent.constructor, dfn, iname );
+        mixinCls( parent.constructor, dfn, iname, true );
     }
 }
 
@@ -713,7 +715,7 @@ function mixinImpl( cls, dest_meta )
  *
  * @return  {undefined}
  */
-function mixMethods( src, dest, vis, iname )
+function mixMethods( src, dest, vis, iname, inparent )
 {
     for ( var f in src )
     {
@@ -733,13 +735,23 @@ function mixMethods( src, dest, vis, iname )
         // TODO: this is a kluge; we'll use proper reflection eventually,
         // but for now, this is how we determine if this is an actual method
         // vs. something that just happens to be on the visibility object
-        if ( !( src[ f ].___$$keywords$$ ) )
+        if ( !( src[ f ] && src[ f ].___$$keywords$$ ) )
         {
             continue;
         }
 
-        var keywords = src[ f ].___$$keywords$$,
-            vis      = keywords['protected'] ? 'protected' : 'public';
+        var keywords = src[ f ].___$$keywords$$;
+
+        // TODO: This is a kluge to handle ES3 fallbacks, which will cause
+        // protected members to appear on the public prototype.  A more
+        // elegant solution is to automatically add the public keyword when
+        // the class is built, so we can just check if keywords[vis] exists.
+        if ( ( vis === 'public' ) && keywords[ 'protected' ] )
+        {
+            continue;
+        }
+
+        vis = keywords[ 'protected' ] ? 'protected' : 'public';
 
         // if abstract, then we are expected to provide the implementation;
         // otherwise, we proxy to the trait's implementation
@@ -747,10 +759,14 @@ function mixMethods( src, dest, vis, iname )
         {
             // copy the abstract definition (N.B. this does not copy the
             // param names, since that is not [yet] important); the
-            // visibility modified is important to prevent de-escalation
+            // visibility modifier is important to prevent de-escalation
             // errors on override
             dest[ vis + ' weak abstract ' + f ] = src[ f ].definition;
         }
+        else if ( inparent && !keywords[ 'abstract' ] )
+        {
+            continue;
+        }
         else
         {
             var vk    = keywords['virtual'],
@@ -815,7 +831,7 @@ function mixMethods( src, dest, vis, iname )
  * @param  {Class}   T     trait
  * @param  {Object}  dfn   definition object of class being mixed into
  * @param  {Array}   tc    trait class object
- * @param  {Class}   base  target supertyep
+ * @param  {Class}   base  target supertype
  *
  * @return  {string}  private member into which C instance shall be stored
  */
