@@ -22,7 +22,7 @@
 /**
  * XXX: tightly coupled
  */
-var util = require( __dirname + '/util' );
+var util = require( './util' );
 
 
 /**
