@@ -1,7 +1,7 @@
 /**
  * Contains basic inheritance mechanism
  *
- *  Copyright (C) 2010, 2011, 2012, 2013, 2014, 2015 Free Software Foundation, Inc.
+ *  Copyright (C) 2010, 2011, 2012, 2013, 2014, 2015, 2016 Free Software Foundation, Inc.
  *
  *  This file is part of GNU ease.js.
  *
@@ -57,7 +57,8 @@ var util         = require( './util' ),
             )
         ),
         require( './VisibilityObjectFactoryFactory' )
-            .fromEnvironment()
+            .fromEnvironment(),
+        require( './ctor/ErrorCtor' )( Error )
     )
 ;
 
