@@ -1,7 +1,7 @@
 /**
  * Tests class module object creation
  *
- *  Copyright (C) 2014 Free Software Foundation, Inc.
+ *  Copyright (C) 2014, 2015 Free Software Foundation, Inc.
  *
  *  This file is part of GNU ease.js.
  *
@@ -24,7 +24,8 @@ require( 'common' ).testCase(
 {
     setUp: function()
     {
-        this.Sut = this.require( 'class' );
+        this.Sut          = this.require( 'class' );
+        this.ClassBuilder = this.require( 'ClassBuilder' );
 
         this.Foo = this.Sut.extend(
         {
@@ -249,6 +250,21 @@ require( 'common' ).testCase(
     },
 
 
+    /**
+     * There are cases---intended for internal use---where it is beneficial
+     * for an object to be treated as though it were actually a class.
+     */
+    'Any object may masquerade as a class': function()
+    {
+        var obj = {};
+
+        // XXX: tightly coupled logic here; refactor things
+        this.ClassBuilder.masquerade( obj );
+
+        this.assertOk( this.Sut.isClass( obj ) );
+    },
+
+
     /**
      * This really should be encapsulated, probably, but it does exist for
      * reference.
